
# Type: participates in


holds between a continuant and a process, where the continuant is somehow involved in the process

URI: [biolink:participates_in](https://w3id.org/biolink/vocab/participates_in)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [Occurrent](Occurrent.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [actively involved in](actively_involved_in.md)

## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0000056 |
| **In Subsets:** | | translator_minimal |

